==> haskell-free-5.0.2-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-free.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: free
version: 5.0.2
id: free-5.0.2-16FX5oswC1HDXTVuKmV2iI
key: free-5.0.2-16FX5oswC1HDXTVuKmV2iI
license: BSD-3-Clause
copyright: Copyright (C) 2008-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/free/
synopsis: Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.
    .
    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.
    .
    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.
    .
    More information on free monads, including examples, can be found in the
    following blog posts:
    <http://comonad.com/reader/2008/monads-for-free/>
    <http://comonad.com/reader/2011/free-monads-for-less/>
category: Control, Monads
abi: e068347b80354832bb7da21745ca2fd1
exposed: True
exposed-modules:
    Control.Alternative.Free Control.Alternative.Free.Final
    Control.Applicative.Free Control.Applicative.Free.Fast
    Control.Applicative.Free.Final Control.Applicative.Trans.Free
    Control.Comonad.Cofree Control.Comonad.Cofree.Class
    Control.Comonad.Trans.Cofree Control.Comonad.Trans.Coiter
    Control.Monad.Free Control.Monad.Free.Ap Control.Monad.Free.Church
    Control.Monad.Free.Class Control.Monad.Free.TH
    Control.Monad.Trans.Free Control.Monad.Trans.Free.Ap
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter
hidden-modules: Data.Functor.Classes.Compat
import-dirs: /usr/lib/ghc-8.4.3/site-local/free-5.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/free-5.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/free-5.0.2
hs-libraries: HSfree-5.0.2-16FX5oswC1HDXTVuKmV2iI
includes:
    free-common.h
depends:
    base-4.11.1.0 bifunctors-5.5.2-8apiYaanV3KFwSUWxSrens
    comonad-5.0.3-DnrjXJ5Aei1JEu8fMrlR9P
    distributive-0.5.3-FetmQwQaxcXKK5vo9ZZR6d mtl-2.2.2
    profunctors-5.2.2-IakD9ZOOFJRiYSnH5jCC9
    semigroupoids-5.2.2-32ANdqHbTvV8WgX9cJIWZA transformers-0.5.5.0
    transformers-base-0.4.5.2-HkOEnilApg71eKub9grpon
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    template-haskell-2.13.0.0 exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf
    containers-0.5.11.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bifunctors-5.5.2-8apiYaanV3KFwSUWxSrens=1d2b589d3fb7e624987b78c775372118
             comonad-5.0.3-DnrjXJ5Aei1JEu8fMrlR9P=719633c22f119a5f8d5f3e41d077a8ad
             distributive-0.5.3-FetmQwQaxcXKK5vo9ZZR6d=86042d6e8705203e681dc0b2bf507441
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             profunctors-5.2.2-IakD9ZOOFJRiYSnH5jCC9=1d508abbc1f63249e29622eb3e284eb1
             semigroupoids-5.2.2-32ANdqHbTvV8WgX9cJIWZA=db1e13079ba7b96d5af77fa45cfaa056
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-base-0.4.5.2-HkOEnilApg71eKub9grpon=3700d08e9c0fb7ac1d166d53bb66cbcb
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
haddock-interfaces: /usr/share/doc/haskell-free/html/free.haddock
haddock-html: /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-free-5.0.2-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-free.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: free
version: 5.0.2
id: free-5.0.2-HgHfyJaNE258DZmQ5rLWWU
key: free-5.0.2-HgHfyJaNE258DZmQ5rLWWU
license: BSD-3-Clause
copyright: Copyright (C) 2008-2015 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/free/
synopsis: Monads for free
description:
    Free monads are useful for many tree-like structures and domain specific languages.
    .
    If @f@ is a '\''Functor'\'' then the free '\''Monad'\'' on @f@ is the type
    of trees whose nodes are labeled with the constructors of @f@. The word
    \"free\" is used in the sense of \"unrestricted\" rather than \"zero-cost\":
    @Free f@ makes no constraining assumptions beyond those given by @f@ and the
    definition of '\''Monad'\''. As used here it is a standard term from the
    mathematical theory of adjoint functors.
    .
    Cofree comonads are dual to free monads. They provide convenient ways to talk
    about branching streams and rose-trees, and can be used to annotate syntax
    trees. The cofree comonad can be seen as a stream parameterized by a '\''Functor'\''
    that controls its branching factor.
    .
    More information on free monads, including examples, can be found in the
    following blog posts:
    <http://comonad.com/reader/2008/monads-for-free/>
    <http://comonad.com/reader/2011/free-monads-for-less/>
category: Control, Monads
abi: 968fe7aec9567e964e91c4091b77ab30
exposed: True
exposed-modules:
    Control.Alternative.Free Control.Alternative.Free.Final
    Control.Applicative.Free Control.Applicative.Free.Fast
    Control.Applicative.Free.Final Control.Applicative.Trans.Free
    Control.Comonad.Cofree Control.Comonad.Cofree.Class
    Control.Comonad.Trans.Cofree Control.Comonad.Trans.Coiter
    Control.Monad.Free Control.Monad.Free.Ap Control.Monad.Free.Church
    Control.Monad.Free.Class Control.Monad.Free.TH
    Control.Monad.Trans.Free Control.Monad.Trans.Free.Ap
    Control.Monad.Trans.Free.Church Control.Monad.Trans.Iter
hidden-modules: Data.Functor.Classes.Compat
import-dirs: /usr/lib/ghc-8.4.3/site-local/free-5.0.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/free-5.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/free-5.0.2
hs-libraries: HSfree-5.0.2-HgHfyJaNE258DZmQ5rLWWU
includes:
    free-common.h
depends:
    base-4.11.1.0 bifunctors-5.5.2-4wyiWXzIUCXDzqUUMQ9wia
    comonad-5.0.3-4v7nuSEPdIgBetSmkb18fm
    distributive-0.5.3-965UA3IOt3u9On3XjmkGHE mtl-2.2.2
    profunctors-5.2.2-KdWNFetrcSrCHbDg3crInJ
    semigroupoids-5.2.2-JN0Iyx1GXG3I17PeKac8zV transformers-0.5.5.0
    transformers-base-0.4.5.2-8XRnUljar8BDHMt3cPCext
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    template-haskell-2.13.0.0 exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf
    containers-0.5.11.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bifunctors-5.5.2-4wyiWXzIUCXDzqUUMQ9wia=da12de376c963f703b55ae573a6b2206
             comonad-5.0.3-4v7nuSEPdIgBetSmkb18fm=6275d7cdedf67fa735e89804aadcdd64
             distributive-0.5.3-965UA3IOt3u9On3XjmkGHE=27afbec73939ed6c0caf9e2b2493bd83
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             profunctors-5.2.2-KdWNFetrcSrCHbDg3crInJ=aa097a8875a5aeac7cc50b794f28178a
             semigroupoids-5.2.2-JN0Iyx1GXG3I17PeKac8zV=d2ed7244fbf87d5e4b6b0644b4344bf5
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-base-0.4.5.2-8XRnUljar8BDHMt3cPCext=38bea391ee10b49a0c9be04e9f005244
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
haddock-interfaces: /usr/share/doc/haskell-free/html/free.haddock
haddock-html: /usr/share/doc/haskell-free/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
